using System;
using System.Collections.Generic;

namespace Oxide.Plugins
{
    [Info("Time Manager", "Mroczny", "1.0.0")]
    [Description("Time Manager for hurtworld")]

    public class Timemanager : HurtworldPlugin
    {
        protected override void LoadDefaultMessages()
        {
            // English
            lang.RegisterMessages(new Dictionary<string, string>()
            {
                ["Day Command"] = "<color=#5B5B5B>»</color> Time set to <color=#FFFFE0>day</color>",
                ["Night Command"] = "<color=#5B5B5B>»</color> Time set to <color=#551A8B>night</color>",
                ["Weather Clear Command"] = "<color=#5B5B5B>»</color> Weather conditions cleared",
                ["No Permission"] = "You don't have permission to use this command. ({PERM})"
            }, this);

            // Polish
            lang.RegisterMessages(new Dictionary<string, string>()
            {
                ["Day Command"] = "<color=#5B5B5B>»</color> Czas ustawiony na <color=#FFFFE0>dzien</color>",
                ["Night Command"] = "<color=#5B5B5B>»</color> Czas ustawiony na <color=#551A8B>noc</color>",
                ["Weather Clear Command"] = "<color=#5B5B5B>»</color> <color=#B2B2B2>Wyczyszczono warunki pogodowe!</color>",
                ["No Permission"] = "Nie masz uprawnien do tej komendy. ({PERM})"
            }, this, "pl");
        }

        protected override void LoadDefaultConfig()
        {
            Config["DayLength"] = 900;
            Config["NightLength"] = 420;
            SaveConfig();
        }

        private void Loaded()
        {
            permission.RegisterPermission("timemanager.woff", this);
            permission.RegisterPermission("timemanager.day", this);
            permission.RegisterPermission("timemanager.night", this);
        }

        private void OnServerInitialized()
        {
            TimeManager.Instance.DayLength = Convert.ToSingle(Config["DayLength"]);
            TimeManager.Instance.NightLength = Convert.ToSingle(Config["NightLength"]);
        }

#if !HURTWORLD
        [ChatCommand("woff")]
        private void WOFFCommand(PlayerSession p, string command, string[] args)
        {
            if (HasPermission(p.SteamId, "timemanager.woff") || p.IsAdmin)
            {
                Server.Command("destroyall RainstormServer");
                Server.Command("destroyall SandstormServer");
                Server.Command("destroyall BlizzardServer");

                hurt.SendChatMessage(p, null, Msg("Weather Clear Command", p.SteamId));

                foreach (PlayerSession players in GameManager.Instance.GetSessions().Values)
                {
                    if (players != null && players.IsLoaded)
                    {
                        EntityStats stats = players.WorldPlayerEntity.GetComponent<EntityStats>();
                        stats.RemoveBinaryEffect(EEntityBinaryEffectType.Wet);
                        stats.RemoveBinaryEffect(EEntityBinaryEffectType.Hypothermia);
                        stats.GetFluidEffect(EEntityFluidEffectType.Dampness).Reset(true);
                    }
                }
            }
            else
            {
                hurt.SendChatMessage(p, null, Msg("No Permission", p.SteamId).Replace("{PERM}", "timemanager." + command));
            }
        }
#endif

        [ChatCommand("day")]
        private void DayCommand(PlayerSession p, string command, string[] args)
        {
            if (HasPermission(p.SteamId, "timemanager.day") || p.IsAdmin)
            {
                Server.Command("settime 0.1");
                hurt.SendChatMessage(p, null, Msg("Day Command", p.SteamId));
            }
            else
            {
                hurt.SendChatMessage(p, null, Msg("No Permission", p.SteamId).Replace("{PERM}", "timemanager." + command));
            }
        }

        [ChatCommand("night")]
        private void NightCommand(PlayerSession p, string command, string[] args)
        {
            if (HasPermission(p.SteamId, "timemanager.night") || p.IsAdmin)
            {
                Server.Command("settime 1");
                hurt.SendChatMessage(p, null, Msg("Night Command", p.SteamId));
            }
            else
            {
                hurt.SendChatMessage(p, null, Msg("No Permission", p.SteamId).Replace("{PERM}", "timemanager." + command));
            }
        }

        private bool HasPermission(object steamId, string perm) => permission.UserHasPermission(steamId.ToString(), perm);
        private string Msg(string msg, object steamID = null) => lang.GetMessage(msg, this, steamID.ToString());
    }
}
